/*
  k2917.h
*/
#ifdef __KERNEL__
/* Base Address and Map Size */
#define K2917ADR  0xFF00
#define K2917SIZE 0x70

/* Register Address */
#define CSER       0x00
#define DOCR       0x04 
#define SCCR       0x06
#define MTCR       0x0A
#define MACHI      0x0C
#define MACLO      0x0E 

#define LAMICR     0x40
#define DONEICR    0x42
#define EMPTYICR   0x44
#define ABTICR     0x46
#define LAMIVR     0x48
#define DONEIVR    0x4A
#define EMPTYIVR   0x4C
#define ABTIVR     0x4E

#define AMR        0x60
#define CMR        0x62
#define CMAR       0x64
#define CWCR       0x66
#define SRR        0x68
#define DLR        0x6A
#define DHR        0x6C
#define CSR        0x6E

/* Interrupt Level & Vectors */
#define INTR_LEVEL      4
#define INTR_VECTOR  0x10

#endif

#include <linux/ioctl.h>

struct k2917_single {
  int naf;
  int data;
  short q,x;
};

struct k2917_al_struct {
  int al_num;
  int size;
  int buffer_size;
  int *action_list;
};

struct k2917_ad_struct {
  int al_num;
  int maxsize;
  int size;
  int *buffer;
};


/* ioctl id */
#define K2917_IOC_MAGIC  'K'
#define K2917_IOC_RESET  _IO(K2917_IOC_MAGIC, 1)
#define K2917_IOC_EI     _IO(K2917_IOC_MAGIC, 2)
#define K2917_IOC_DI     _IO(K2917_IOC_MAGIC, 3)
#define K2917_IOC_SETCR  _IO(K2917_IOC_MAGIC, 4)
#define K2917_IOC_WLAM   _IO(K2917_IOC_MAGIC, 5)
#define K2917_IOC_CAMR16 _IOWR(K2917_IOC_MAGIC, 6,struct k2917_single)
#define K2917_IOC_CAMR24 _IOWR(K2917_IOC_MAGIC, 7,struct k2917_single)
#define K2917_IOC_CAMW16 _IOWR(K2917_IOC_MAGIC, 8,struct k2917_single)
#define K2917_IOC_CAMW24 _IOWR(K2917_IOC_MAGIC, 9,struct k2917_single)
#define K2917_IOC_CAMC   _IOWR(K2917_IOC_MAGIC,10,struct k2917_single)
#define K2917_IOC_ALREG    _IOW(K2917_IOC_MAGIC,11,struct k2917_al_struct)
#define K2917_IOC_ALUNREG  _IO(K2917_IOC_MAGIC,12)
#define K2917_IOC_EXEC_LA1 _IOWR(K2917_IOC_MAGIC,13,struct k2917_ad_struct)
#define K2917_IOC_EXEC_LA2 _IOWR(K2917_IOC_MAGIC,14,struct k2917_ad_struct)
#define K2917_IOC_EXEC_LA3 _IOWR(K2917_IOC_MAGIC,15,struct k2917_ad_struct)

#define K2917_IOC_MAXNR  15

#define NAF(n,a,f) ( (((n)&0x1F)<<9) | (((a)&0x0F)<<5) | ((f)&0x1F) )
#define NAFMASK    0x3FFF
#define NAFGetF(x)    (  (x)    &0x1F )
#define NAFGetA(x)    ( ((x)>>5)&0x0F )
#define NAFGetN(x)    ( ((x)>>9)&0x1F )
#define NAFCHKF16(x)  ( ((x)>>4)&0x01 )
#define NAFCHKF8(x)   ( ((x)>>3)&0x01 )
#define QS_READ    0x10000000
#define ASCAN(x)   ( 0x20000000 | (((x)&0x0F)<<24) )
#define ASCHK(x)   ( (x)&0x20000000 )
#define ASGetAM(x) ( ((x)>>24)&0xF )
#define LDencode(q,x,n,a,d) ( ((q)<<31) | ((x)<<30) | ((n)<<20) | \
                              ((a)<<16) | ((d)&0xFFFF) )
#define K3922SR_WMASK 0x0387
